Class: Google::Apis::DialogflowV2beta1::GoogleCloudDialogflowV2beta1AnalyzeContentResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dialogflow_v2beta1/classes.rb,
lib/google/apis/dialogflow_v2beta1/representations.rb,
lib/google/apis/dialogflow_v2beta1/representations.rb

Overview

The response message for Participants.AnalyzeContent.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDialogflowV2beta1AnalyzeContentResponse

Returns a new instance of GoogleCloudDialogflowV2beta1AnalyzeContentResponse.



12795
12796
12797
# File 'lib/google/apis/dialogflow_v2beta1/classes.rb', line 12795

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#automated_agent_replyGoogle::Apis::DialogflowV2beta1::GoogleCloudDialogflowV2beta1AutomatedAgentReply

Represents a response from an automated agent. Corresponds to the JSON property automatedAgentReply



12751
12752
12753
# File 'lib/google/apis/dialogflow_v2beta1/classes.rb', line 12751

def automated_agent_reply
  @automated_agent_reply
end

#dtmf_parametersGoogle::Apis::DialogflowV2beta1::GoogleCloudDialogflowV2beta1DtmfParameters

The message in the response that indicates the parameters of DTMF. Corresponds to the JSON property dtmfParameters



12756
12757
12758
# File 'lib/google/apis/dialogflow_v2beta1/classes.rb', line 12756

def dtmf_parameters
  @dtmf_parameters
end

#end_user_suggestion_resultsArray<Google::Apis::DialogflowV2beta1::GoogleCloudDialogflowV2beta1SuggestionResult>

The suggestions for end user. The order is the same as HumanAgentAssistantConfig.SuggestionConfig.feature_configs of HumanAgentAssistantConfig.end_user_suggestion_config. Same as human_agent_suggestion_results, any failure of Agent Assist features will not lead to the overall failure of an AnalyzeContent API call. Instead, the features will fail silently with the error field set in the corresponding SuggestionResult. Corresponds to the JSON property endUserSuggestionResults



12767
12768
12769
# File 'lib/google/apis/dialogflow_v2beta1/classes.rb', line 12767

def end_user_suggestion_results
  @end_user_suggestion_results
end

#human_agent_suggestion_resultsArray<Google::Apis::DialogflowV2beta1::GoogleCloudDialogflowV2beta1SuggestionResult>

The suggestions for most recent human agent. The order is the same as HumanAgentAssistantConfig.SuggestionConfig.feature_configs of HumanAgentAssistantConfig.human_agent_suggestion_config. Note that any failure of Agent Assist features will not lead to the overall failure of an AnalyzeContent API call. Instead, the features will fail silently with the error field set in the corresponding SuggestionResult. Corresponds to the JSON property humanAgentSuggestionResults



12777
12778
12779
# File 'lib/google/apis/dialogflow_v2beta1/classes.rb', line 12777

def human_agent_suggestion_results
  @human_agent_suggestion_results
end

#messageGoogle::Apis::DialogflowV2beta1::GoogleCloudDialogflowV2beta1Message

Represents a message posted into a conversation. Corresponds to the JSON property message



12782
12783
12784
# File 'lib/google/apis/dialogflow_v2beta1/classes.rb', line 12782

def message
  @message
end

#reply_audioGoogle::Apis::DialogflowV2beta1::GoogleCloudDialogflowV2beta1OutputAudio

Represents the natural language speech audio to be played to the end user. Corresponds to the JSON property replyAudio



12787
12788
12789
# File 'lib/google/apis/dialogflow_v2beta1/classes.rb', line 12787

def reply_audio
  @reply_audio
end

#reply_textString

Output only. The output text content. This field is set if the automated agent responded with text to show to the user. Corresponds to the JSON property replyText

Returns:

  • (String)


12793
12794
12795
# File 'lib/google/apis/dialogflow_v2beta1/classes.rb', line 12793

def reply_text
  @reply_text
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



12800
12801
12802
12803
12804
12805
12806
12807
12808
# File 'lib/google/apis/dialogflow_v2beta1/classes.rb', line 12800

def update!(**args)
  @automated_agent_reply = args[:automated_agent_reply] if args.key?(:automated_agent_reply)
  @dtmf_parameters = args[:dtmf_parameters] if args.key?(:dtmf_parameters)
  @end_user_suggestion_results = args[:end_user_suggestion_results] if args.key?(:end_user_suggestion_results)
  @human_agent_suggestion_results = args[:human_agent_suggestion_results] if args.key?(:human_agent_suggestion_results)
  @message = args[:message] if args.key?(:message)
  @reply_audio = args[:reply_audio] if args.key?(:reply_audio)
  @reply_text = args[:reply_text] if args.key?(:reply_text)
end