Class: Google::Apis::DialogflowV2beta1::GoogleCloudDialogflowV2beta1EnvironmentHistory
- Inherits:
-
Object
- Object
- Google::Apis::DialogflowV2beta1::GoogleCloudDialogflowV2beta1EnvironmentHistory
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dialogflow_v2beta1/classes.rb,
lib/google/apis/dialogflow_v2beta1/representations.rb,
lib/google/apis/dialogflow_v2beta1/representations.rb
Overview
The response message for Environments.GetEnvironmentHistory.
Instance Attribute Summary collapse
-
#entries ⇒ Array<Google::Apis::DialogflowV2beta1::GoogleCloudDialogflowV2beta1EnvironmentHistoryEntry>
Output only.
-
#next_page_token ⇒ String
Output only.
-
#parent ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDialogflowV2beta1EnvironmentHistory
constructor
A new instance of GoogleCloudDialogflowV2beta1EnvironmentHistory.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDialogflowV2beta1EnvironmentHistory
Returns a new instance of GoogleCloudDialogflowV2beta1EnvironmentHistory.
14883 14884 14885 |
# File 'lib/google/apis/dialogflow_v2beta1/classes.rb', line 14883 def initialize(**args) update!(**args) end |
Instance Attribute Details
#entries ⇒ Array<Google::Apis::DialogflowV2beta1::GoogleCloudDialogflowV2beta1EnvironmentHistoryEntry>
Output only. The list of agent environments. There will be a maximum number of
items returned based on the page_size field in the request.
Corresponds to the JSON property entries
14868 14869 14870 |
# File 'lib/google/apis/dialogflow_v2beta1/classes.rb', line 14868 def entries @entries end |
#next_page_token ⇒ String
Output only. Token to retrieve the next page of results, or empty if there are
no more results in the list.
Corresponds to the JSON property nextPageToken
14874 14875 14876 |
# File 'lib/google/apis/dialogflow_v2beta1/classes.rb', line 14874 def next_page_token @next_page_token end |
#parent ⇒ String
Output only. The name of the environment this history is for. Supported
formats: - projects//agent/environments/ - projects//locations//agent/
environments/
Corresponds to the JSON property parent
14881 14882 14883 |
# File 'lib/google/apis/dialogflow_v2beta1/classes.rb', line 14881 def parent @parent end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
14888 14889 14890 14891 14892 |
# File 'lib/google/apis/dialogflow_v2beta1/classes.rb', line 14888 def update!(**args) @entries = args[:entries] if args.key?(:entries) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @parent = args[:parent] if args.key?(:parent) end |