Class: Google::Apis::DialogflowV2beta1::GoogleCloudDialogflowV2beta1ListToolsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dialogflow_v2beta1/classes.rb,
lib/google/apis/dialogflow_v2beta1/representations.rb,
lib/google/apis/dialogflow_v2beta1/representations.rb

Overview

Response of ListTools.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDialogflowV2beta1ListToolsResponse

Returns a new instance of GoogleCloudDialogflowV2beta1ListToolsResponse.



19811
19812
19813
# File 'lib/google/apis/dialogflow_v2beta1/classes.rb', line 19811

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#next_page_tokenString

Token to retrieve the next page of results, or empty if there are no more results in the list. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


19804
19805
19806
# File 'lib/google/apis/dialogflow_v2beta1/classes.rb', line 19804

def next_page_token
  @next_page_token
end

#toolsArray<Google::Apis::DialogflowV2beta1::GoogleCloudDialogflowV2beta1Tool>

List of tools retrieved. Corresponds to the JSON property tools



19809
19810
19811
# File 'lib/google/apis/dialogflow_v2beta1/classes.rb', line 19809

def tools
  @tools
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



19816
19817
19818
19819
# File 'lib/google/apis/dialogflow_v2beta1/classes.rb', line 19816

def update!(**args)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @tools = args[:tools] if args.key?(:tools)
end