Class: Google::Apis::DialogflowV2beta1::GoogleCloudDialogflowV2beta1RestoreAgentRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dialogflow_v2beta1/classes.rb,
lib/google/apis/dialogflow_v2beta1/representations.rb,
lib/google/apis/dialogflow_v2beta1/representations.rb

Overview

The request message for Agents.RestoreAgent.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDialogflowV2beta1RestoreAgentRequest

Returns a new instance of GoogleCloudDialogflowV2beta1RestoreAgentRequest.



20880
20881
20882
# File 'lib/google/apis/dialogflow_v2beta1/classes.rb', line 20880

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#agent_contentString

Zip compressed raw byte content for agent. Corresponds to the JSON property agentContent NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


20868
20869
20870
# File 'lib/google/apis/dialogflow_v2beta1/classes.rb', line 20868

def agent_content
  @agent_content
end

#agent_uriString

The URI to a Google Cloud Storage file containing the agent to restore. Note: The URI must start with "gs://". Dialogflow performs a read operation for the Cloud Storage object on the caller's behalf, so your request authentication must have read permissions for the object. For more information, see Dialogflow access control. Corresponds to the JSON property agentUri

Returns:

  • (String)


20878
20879
20880
# File 'lib/google/apis/dialogflow_v2beta1/classes.rb', line 20878

def agent_uri
  @agent_uri
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



20885
20886
20887
20888
# File 'lib/google/apis/dialogflow_v2beta1/classes.rb', line 20885

def update!(**args)
  @agent_content = args[:agent_content] if args.key?(:agent_content)
  @agent_uri = args[:agent_uri] if args.key?(:agent_uri)
end