Class: Google::Apis::DialogflowV2beta1::GoogleCloudDialogflowV2beta1SearchKnowledgeRequestSearchConfigBoostSpecsBoostSpecConditionBoostSpec
- Inherits:
-
Object
- Object
- Google::Apis::DialogflowV2beta1::GoogleCloudDialogflowV2beta1SearchKnowledgeRequestSearchConfigBoostSpecsBoostSpecConditionBoostSpec
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dialogflow_v2beta1/classes.rb,
lib/google/apis/dialogflow_v2beta1/representations.rb,
lib/google/apis/dialogflow_v2beta1/representations.rb
Overview
Boost applies to documents which match a condition.
Instance Attribute Summary collapse
-
#boost ⇒ Float
Optional.
-
#boost_control_spec ⇒ Google::Apis::DialogflowV2beta1::GoogleCloudDialogflowV2beta1SearchKnowledgeRequestSearchConfigBoostSpecsBoostSpecConditionBoostSpecBoostControlSpec
Specification for custom ranking based on customer specified attribute value.
-
#condition ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDialogflowV2beta1SearchKnowledgeRequestSearchConfigBoostSpecsBoostSpecConditionBoostSpec
constructor
A new instance of GoogleCloudDialogflowV2beta1SearchKnowledgeRequestSearchConfigBoostSpecsBoostSpecConditionBoostSpec.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDialogflowV2beta1SearchKnowledgeRequestSearchConfigBoostSpecsBoostSpecConditionBoostSpec
Returns a new instance of GoogleCloudDialogflowV2beta1SearchKnowledgeRequestSearchConfigBoostSpecsBoostSpecConditionBoostSpec.
21199 21200 21201 |
# File 'lib/google/apis/dialogflow_v2beta1/classes.rb', line 21199 def initialize(**args) update!(**args) end |
Instance Attribute Details
#boost ⇒ Float
Optional. Strength of the condition boost, which should be in [-1, 1].
Negative boost means demotion. Default is 0.0. Setting to 1.0 gives the
document a big promotion. However, it does not necessarily mean that the
boosted document will be the top result at all times, nor that other documents
will be excluded. Results could still be shown even when none of them matches
the condition. And results that are significantly more relevant to the search
query can still trump your heavily favored but irrelevant documents. Setting
to -1.0 gives the document a big demotion. However, results that are deeply
relevant might still be shown. The document will have an upstream battle to
get a fairly high ranking, but it is not blocked out completely. Setting to 0.
0 means no boost applied. The boosting condition is ignored.
Corresponds to the JSON property boost
21182 21183 21184 |
# File 'lib/google/apis/dialogflow_v2beta1/classes.rb', line 21182 def boost @boost end |
#boost_control_spec ⇒ Google::Apis::DialogflowV2beta1::GoogleCloudDialogflowV2beta1SearchKnowledgeRequestSearchConfigBoostSpecsBoostSpecConditionBoostSpecBoostControlSpec
Specification for custom ranking based on customer specified attribute value.
It provides more controls for customized ranking than the simple (condition,
boost) combination above.
Corresponds to the JSON property boostControlSpec
21189 21190 21191 |
# File 'lib/google/apis/dialogflow_v2beta1/classes.rb', line 21189 def boost_control_spec @boost_control_spec end |
#condition ⇒ String
Optional. An expression which specifies a boost condition. The syntax and
supported fields are the same as a filter expression. Examples: * To boost
documents with document ID "doc_1" or "doc_2", and color "Red" or "Blue": * (
id: ANY("doc_1", "doc_2")) AND (color: ANY("Red","Blue"))
Corresponds to the JSON property condition
21197 21198 21199 |
# File 'lib/google/apis/dialogflow_v2beta1/classes.rb', line 21197 def condition @condition end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
21204 21205 21206 21207 21208 |
# File 'lib/google/apis/dialogflow_v2beta1/classes.rb', line 21204 def update!(**args) @boost = args[:boost] if args.key?(:boost) @boost_control_spec = args[:boost_control_spec] if args.key?(:boost_control_spec) @condition = args[:condition] if args.key?(:condition) end |