Class: Google::Apis::DialogflowV2beta1::GoogleCloudDialogflowV2beta1SuggestConversationSummaryResponse
- Inherits:
-
Object
- Object
- Google::Apis::DialogflowV2beta1::GoogleCloudDialogflowV2beta1SuggestConversationSummaryResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dialogflow_v2beta1/classes.rb,
lib/google/apis/dialogflow_v2beta1/representations.rb,
lib/google/apis/dialogflow_v2beta1/representations.rb
Overview
The response message for Conversations.SuggestConversationSummary.
Instance Attribute Summary collapse
-
#context_size ⇒ Fixnum
Number of messages prior to and including last_conversation_message used to compile the suggestion.
-
#latest_message ⇒ String
The name of the latest conversation message used as context for compiling suggestion.
-
#summary ⇒ Google::Apis::DialogflowV2beta1::GoogleCloudDialogflowV2beta1SuggestConversationSummaryResponseSummary
Generated summary for a conversation.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDialogflowV2beta1SuggestConversationSummaryResponse
constructor
A new instance of GoogleCloudDialogflowV2beta1SuggestConversationSummaryResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDialogflowV2beta1SuggestConversationSummaryResponse
Returns a new instance of GoogleCloudDialogflowV2beta1SuggestConversationSummaryResponse.
22039 22040 22041 |
# File 'lib/google/apis/dialogflow_v2beta1/classes.rb', line 22039 def initialize(**args) update!(**args) end |
Instance Attribute Details
#context_size ⇒ Fixnum
Number of messages prior to and including last_conversation_message used to
compile the suggestion. It may be smaller than the SuggestSummaryRequest.
context_size field in the request if there weren't that many messages in the
conversation.
Corresponds to the JSON property contextSize
22026 22027 22028 |
# File 'lib/google/apis/dialogflow_v2beta1/classes.rb', line 22026 def context_size @context_size end |
#latest_message ⇒ String
The name of the latest conversation message used as context for compiling
suggestion. Format: projects//locations//conversations//messages/.
Corresponds to the JSON property latestMessage
22032 22033 22034 |
# File 'lib/google/apis/dialogflow_v2beta1/classes.rb', line 22032 def @latest_message end |
#summary ⇒ Google::Apis::DialogflowV2beta1::GoogleCloudDialogflowV2beta1SuggestConversationSummaryResponseSummary
Generated summary for a conversation.
Corresponds to the JSON property summary
22037 22038 22039 |
# File 'lib/google/apis/dialogflow_v2beta1/classes.rb', line 22037 def summary @summary end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
22044 22045 22046 22047 22048 |
# File 'lib/google/apis/dialogflow_v2beta1/classes.rb', line 22044 def update!(**args) @context_size = args[:context_size] if args.key?(:context_size) @latest_message = args[:latest_message] if args.key?(:latest_message) @summary = args[:summary] if args.key?(:summary) end |