Class: Google::Apis::DialogflowV2beta1::GoogleCloudDialogflowV2beta1GeneratorEvaluation
- Inherits:
-
Object
- Object
- Google::Apis::DialogflowV2beta1::GoogleCloudDialogflowV2beta1GeneratorEvaluation
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dialogflow_v2beta1/classes.rb,
lib/google/apis/dialogflow_v2beta1/representations.rb,
lib/google/apis/dialogflow_v2beta1/representations.rb
Overview
Represents evaluation result of a generator.
Instance Attribute Summary collapse
-
#complete_time ⇒ String
Output only.
-
#create_time ⇒ String
Output only.
-
#display_name ⇒ String
Optional.
-
#evaluation_status ⇒ Google::Apis::DialogflowV2beta1::GoogleCloudDialogflowV2beta1EvaluationStatus
A common evalaution pipeline status.
-
#generator_evaluation_config ⇒ Google::Apis::DialogflowV2beta1::GoogleCloudDialogflowV2beta1GeneratorEvaluationConfig
Generator evaluation input config.
-
#initial_generator ⇒ Google::Apis::DialogflowV2beta1::GoogleCloudDialogflowV2beta1Generator
LLM generator.
-
#name ⇒ String
Output only.
-
#satisfies_pzi ⇒ Boolean
(also: #satisfies_pzi?)
Output only.
-
#satisfies_pzs ⇒ Boolean
(also: #satisfies_pzs?)
Output only.
-
#summarization_metrics ⇒ Google::Apis::DialogflowV2beta1::GoogleCloudDialogflowV2beta1SummarizationEvaluationMetrics
Evaluation metrics for summarization generator.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDialogflowV2beta1GeneratorEvaluation
constructor
A new instance of GoogleCloudDialogflowV2beta1GeneratorEvaluation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDialogflowV2beta1GeneratorEvaluation
Returns a new instance of GoogleCloudDialogflowV2beta1GeneratorEvaluation.
15851 15852 15853 |
# File 'lib/google/apis/dialogflow_v2beta1/classes.rb', line 15851 def initialize(**args) update!(**args) end |
Instance Attribute Details
#complete_time ⇒ String
Output only. Completion time of this generator evaluation.
Corresponds to the JSON property completeTime
15797 15798 15799 |
# File 'lib/google/apis/dialogflow_v2beta1/classes.rb', line 15797 def complete_time @complete_time end |
#create_time ⇒ String
Output only. Creation time of this generator evaluation.
Corresponds to the JSON property createTime
15802 15803 15804 |
# File 'lib/google/apis/dialogflow_v2beta1/classes.rb', line 15802 def create_time @create_time end |
#display_name ⇒ String
Optional. The display name of the generator evaluation. At most 64 bytes long.
Corresponds to the JSON property displayName
15807 15808 15809 |
# File 'lib/google/apis/dialogflow_v2beta1/classes.rb', line 15807 def display_name @display_name end |
#evaluation_status ⇒ Google::Apis::DialogflowV2beta1::GoogleCloudDialogflowV2beta1EvaluationStatus
A common evalaution pipeline status.
Corresponds to the JSON property evaluationStatus
15812 15813 15814 |
# File 'lib/google/apis/dialogflow_v2beta1/classes.rb', line 15812 def evaluation_status @evaluation_status end |
#generator_evaluation_config ⇒ Google::Apis::DialogflowV2beta1::GoogleCloudDialogflowV2beta1GeneratorEvaluationConfig
Generator evaluation input config.
Corresponds to the JSON property generatorEvaluationConfig
15817 15818 15819 |
# File 'lib/google/apis/dialogflow_v2beta1/classes.rb', line 15817 def generator_evaluation_config @generator_evaluation_config end |
#initial_generator ⇒ Google::Apis::DialogflowV2beta1::GoogleCloudDialogflowV2beta1Generator
LLM generator.
Corresponds to the JSON property initialGenerator
15822 15823 15824 |
# File 'lib/google/apis/dialogflow_v2beta1/classes.rb', line 15822 def initial_generator @initial_generator end |
#name ⇒ String
Output only. Identifier. The resource name of the evaluation. Format:
projects//locations//generators// evaluations/
Corresponds to the JSON property name
15828 15829 15830 |
# File 'lib/google/apis/dialogflow_v2beta1/classes.rb', line 15828 def name @name end |
#satisfies_pzi ⇒ Boolean Also known as: satisfies_pzi?
Output only. A read only boolean field reflecting Zone Isolation status of the
model. The field is an aggregated value of ZI status of its underlying
dependencies. See more details in go/zicy-resource-placement#resource-status
Corresponds to the JSON property satisfiesPzi
15835 15836 15837 |
# File 'lib/google/apis/dialogflow_v2beta1/classes.rb', line 15835 def satisfies_pzi @satisfies_pzi end |
#satisfies_pzs ⇒ Boolean Also known as: satisfies_pzs?
Output only. A read only boolean field reflecting Zone Separation status of
the model. The field is an aggregated value of ZS status of its underlying
dependencies. See more details in go/zicy-resource-placement#resource-status
Corresponds to the JSON property satisfiesPzs
15843 15844 15845 |
# File 'lib/google/apis/dialogflow_v2beta1/classes.rb', line 15843 def satisfies_pzs @satisfies_pzs end |
#summarization_metrics ⇒ Google::Apis::DialogflowV2beta1::GoogleCloudDialogflowV2beta1SummarizationEvaluationMetrics
Evaluation metrics for summarization generator.
Corresponds to the JSON property summarizationMetrics
15849 15850 15851 |
# File 'lib/google/apis/dialogflow_v2beta1/classes.rb', line 15849 def summarization_metrics @summarization_metrics end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
15856 15857 15858 15859 15860 15861 15862 15863 15864 15865 15866 15867 |
# File 'lib/google/apis/dialogflow_v2beta1/classes.rb', line 15856 def update!(**args) @complete_time = args[:complete_time] if args.key?(:complete_time) @create_time = args[:create_time] if args.key?(:create_time) @display_name = args[:display_name] if args.key?(:display_name) @evaluation_status = args[:evaluation_status] if args.key?(:evaluation_status) @generator_evaluation_config = args[:generator_evaluation_config] if args.key?(:generator_evaluation_config) @initial_generator = args[:initial_generator] if args.key?(:initial_generator) @name = args[:name] if args.key?(:name) @satisfies_pzi = args[:satisfies_pzi] if args.key?(:satisfies_pzi) @satisfies_pzs = args[:satisfies_pzs] if args.key?(:satisfies_pzs) @summarization_metrics = args[:summarization_metrics] if args.key?(:summarization_metrics) end |