Class: Google::Apis::DialogflowV2beta1::GoogleCloudDialogflowV2beta1ListPhoneNumbersResponse
- Inherits:
-
Object
- Object
- Google::Apis::DialogflowV2beta1::GoogleCloudDialogflowV2beta1ListPhoneNumbersResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dialogflow_v2beta1/classes.rb,
lib/google/apis/dialogflow_v2beta1/representations.rb,
lib/google/apis/dialogflow_v2beta1/representations.rb
Overview
The response message for PhoneNumbers.ListPhoneNumbers.
Instance Attribute Summary collapse
-
#next_page_token ⇒ String
Token to retrieve the next page of results, or empty if there are no more results in the list.
-
#phone_numbers ⇒ Array<Google::Apis::DialogflowV2beta1::GoogleCloudDialogflowV2beta1PhoneNumber>
The list of
PhoneNumberresources.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDialogflowV2beta1ListPhoneNumbersResponse
constructor
A new instance of GoogleCloudDialogflowV2beta1ListPhoneNumbersResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDialogflowV2beta1ListPhoneNumbersResponse
Returns a new instance of GoogleCloudDialogflowV2beta1ListPhoneNumbersResponse.
19704 19705 19706 |
# File 'lib/google/apis/dialogflow_v2beta1/classes.rb', line 19704 def initialize(**args) update!(**args) end |
Instance Attribute Details
#next_page_token ⇒ String
Token to retrieve the next page of results, or empty if there are no more
results in the list.
Corresponds to the JSON property nextPageToken
19696 19697 19698 |
# File 'lib/google/apis/dialogflow_v2beta1/classes.rb', line 19696 def next_page_token @next_page_token end |
#phone_numbers ⇒ Array<Google::Apis::DialogflowV2beta1::GoogleCloudDialogflowV2beta1PhoneNumber>
The list of PhoneNumber resources. There is a maximum number of items
returned based on the page_size field in the request.
Corresponds to the JSON property phoneNumbers
19702 19703 19704 |
# File 'lib/google/apis/dialogflow_v2beta1/classes.rb', line 19702 def phone_numbers @phone_numbers end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
19709 19710 19711 19712 |
# File 'lib/google/apis/dialogflow_v2beta1/classes.rb', line 19709 def update!(**args) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @phone_numbers = args[:phone_numbers] if args.key?(:phone_numbers) end |